Learn R Programming

survregVB (version 0.0.2)

elbo_cluster: Calculates the variational Bayes convergence criteria, evidence lower bound (ELBO), optimized in survregVB.frailty.fit.

Description

Calculates the variational Bayes convergence criteria, evidence lower bound (ELBO), optimized in survregVB.frailty.fit.

Usage

elbo_cluster(
  y,
  X,
  delta,
  alpha_0,
  omega_0,
  mu_0,
  v_0,
  lambda_0,
  eta_0,
  alpha,
  omega,
  mu,
  Sigma,
  tau,
  sigma,
  lambda,
  eta,
  expectation_b,
  cluster
)

Value

The evidence lower bound (ELBO).

Arguments

y

A vector of observed log-transformed survival times.

X

A design matrix including covariates with first column of ones to represent the intercept.

delta

A binary vector indicating right censoring.

alpha_0

The shape hyperparameter \(\alpha_0\) of the prior distribution of the scale parameter, b.

omega_0

The shape hyperparameter \(\omega_0\) of the prior distribution of the scale parameter, b.

mu_0

Hyperparameter \(\mu_0\), a vector of means, of the prior distribution of the vector of coefficients, \(\beta\).

v_0

The precision (inverse variance) hyperparameter \(v_0\), of the prior distribution of the vector of coefficients, \(\beta\).

lambda_0

The shape hyperparameter \(\lambda_0\) of the prior distribution of the frailty variance, \(\sigma_\gamma^2\).

eta_0

The scale hyperparameter \(\eta_0\) of the prior distribution of the frailty variance, \(\sigma_\gamma^2\).

alpha

The shape parameter \(\alpha^*\) of \(q^*(b)\).

omega

The scale parameter \(\omega^*\) of \(q^*(b)\).

mu

Parameter \(\mu^*\) of \(q^*(\beta)\), a vector of means.

Sigma

Parameter \(\Sigma^*\) of \(q^*(\beta)\), a covariance matrix.

tau

Parameter \(\tau^*\) of \(q^*(\gamma_i)\), a vector of means.

sigma

Parameter \(\sigma^{2*}_i\) of \(q^*(\gamma_i)\), a vector of variance.

lambda

The shape parameter \(\lambda^*\) of \(q^*(\sigma^2_\gamma)\).

eta

The scale parameter \(\eta^*\) of \(q^*(\sigma^2_\gamma)\).

expectation_b

The expected value of b.

cluster

A numeric vector indicating the cluster assignment for each observation.

See Also

survregVB.fit