Learn R Programming

survregVB (version 0.0.2)

mu_star: Calculates parameter \(\mu^*\) of \(q^*(\beta)\) to optimize the evidence based lower bound (ELBO) in survregVB.fit.

Description

Calculates parameter \(\mu^*\) of \(q^*(\beta)\) to optimize the evidence based lower bound (ELBO) in survregVB.fit.

Usage

mu_star(y, X, delta, mu_0, v_0, alpha, omega, mu, Sigma, expectation_b)

Value

Parameter \(\mu^*\) of \(q^*(\beta)\).

Arguments

y

A vector of observed log-transformed survival times.

X

A design matrix including covariates with first column of ones to represent the intercept.

delta

A binary vector indicating right censoring.

mu_0

Hyperparameter \(\mu_0\), a vector of means, of the prior distribution of the vector of coefficients, \(\beta\).

v_0

The precision (inverse variance) hyperparameter \(v_0\), of the prior distribution of the vector of coefficients, \(\beta\).

alpha

The shape parameter \(\alpha^*\) of \(q^*(b)\).

omega

The scale parameter \(\omega^*\) of \(q^*(b)\).

mu

Parameter \(\mu^*\) of \(q^*(\beta)\), a vector of means.

Sigma

Parameter \(\Sigma^*\) of \(q^*(\beta)\), a covariance matrix.

expectation_b

The expected value of b.

See Also

survregVB.fit