Learn R Programming

survregVB (version 0.0.2)

mu_star_cluster: Calculates parameter \(\mu^*\) of \(q^*(\beta)\) to optimize the evidence based lower bound (ELBO) in survregVB.frailty.fit.

Description

Calculates parameter \(\mu^*\) of \(q^*(\beta)\) to optimize the evidence based lower bound (ELBO) in survregVB.frailty.fit.

Usage

mu_star_cluster(
  y,
  X,
  delta,
  mu_0,
  v_0,
  alpha,
  omega,
  mu,
  Sigma,
  tau,
  expectation_b,
  cluster
)

Value

Parameter \(\mu^*\) of \(q^*(\beta)\)

Arguments

y

A vector of observed log-transformed survival times.

X

A design matrix including covariates with first column of ones to represent the intercept.

delta

A binary vector indicating right censoring.

mu_0

Hyperparameter \(\mu_0\), a vector of means, of the prior distribution of the vector of coefficients, \(\beta\).

v_0

The precision (inverse variance) hyperparameter \(v_0\), of the prior distribution of the vector of coefficients, \(\beta\).

alpha

The shape parameter \(\alpha^*\) of \(q^*(b)\).

omega

The scale parameter \(\omega^*\) of \(q^*(b)\).

mu

Parameter \(\mu^*\) of \(q^*(\beta)\), a vector of means.

Sigma

Parameter \(\Sigma^*\) of \(q^*(\beta)\), a covariance matrix.

tau

Parameter \(\tau^*\) of \(q^*(\gamma_i)\), a vector of means.

expectation_b

The expected value of b.

cluster

A numeric vector indicating the cluster assignment for each observation.

See Also

survregVB.frailty.fit