Learn R Programming

survregVB (version 0.0.2)

omega_star: Calculates parameter \(\omega^*\) of \(q^*(b)\) to optimize the evidence based lower bound (ELBO) in survregVB.fit.

Description

Calculates parameter \(\omega^*\) of \(q^*(b)\) to optimize the evidence based lower bound (ELBO) in survregVB.fit.

Usage

omega_star(y, X, delta, omega_0, mu, expectation_b)

Value

Parameter \(\omega^*\) of \(q^*(b)\).

Arguments

y

A vector of observed log-transformed survival times.

X

A design matrix including covariates with first column of ones to represent the intercept.

delta

A binary vector indicating right censoring.

omega_0

The shape hyperparameter \(\omega_0\) of the prior distribution of the scale parameter, b.

mu

Parameter \(\mu^*\) of \(q^*(\beta)\), a vector of means.

expectation_b

The expected value of b.

See Also

survregVB.fit