survregVB.frailty.fit.Calculates parameter \(\omega^*\) of \(q^*(b)\) to optimize the evidence
based lower bound (ELBO) in survregVB.frailty.fit.
omega_star_cluster(y, X, delta, omega_0, mu, tau, expectation_b, cluster)Parameter \(\omega^*\) of \(q^*(b)\).
A vector of observed log-transformed survival times.
A design matrix including covariates with first column of ones to represent the intercept.
A binary vector indicating right censoring.
The shape hyperparameter \(\omega_0\) of the prior distribution of the scale parameter, b.
Parameter \(\mu^*\) of \(q^*(\beta)\), a vector of means.
Parameter \(\tau^*\) of \(q^*(\gamma_i)\), a vector of means.
The expected value of b.
A numeric vector indicating the cluster assignment for each observation.
survregVB.frailty.fit