| survregVB.object | R Documentation |
This class of objects is returned by the survregVB function to represent
a fitted parametric log-logistic accelerated failure time (AFT) survival
model. Objects of this class have methods for the functions print
and summary.
For approximate posterior distributions:
q^*(\beta), a N_p(\mu^*,\Sigma^*) density function, and
q^*(b), an \text{Inverse-Gamma}(\alpha^*,\omega^*)
density function,
the components of this class are:
ELBO: The final value of the Evidence Lower Bound (ELBO)
at the last iteration.
alpha: The shape parameter \alpha^* of q^*(b).
omega: The scale parameter \omega^* of q^*(b).
mu: Parameter \mu^* of q^*(\beta), a vector
of means.
Sigma: Parameter \Sigma^* of q^*(\beta), a
covariance matrix.
na.action: A missing-data filter function, applied to the
model.frame, after any subset argument has been used.
iterations: The number of iterations performed by the VB
algorithm: before converging or reaching max_iteration.
n: The number of observations.
call: The function call used to invoke the survregVB
method.
not_converged: A boolean indicating if the algorithm
converged.
TRUE: If the algorithm did not converge prior to
achieving max_iteration.
NULL: If the algorithm converged successfully.
If survregVB was called with shared frailty (with the cluster
argument), for approximate posterior distributions:
q^*(\sigma^2_\gamma), an \text{Inverse-Gamma}(\lambda^*,\eta^*)
density function,
q^*(\gamma_i), a N(\tau^*_i,\sigma^{2*}_i) density function,
for i=1,...,K clusters, and
the additional components are present:
lambda: The shape parameter \lambda^* of
q^*(\sigma^2_\gamma).
eta: The scale parameter \eta^* of
q^*(\sigma^2_\gamma).
tau: Parameter \tau^*_i of q^*(\gamma_i), a
vector of means.
sigma: Parameter \sigma^{2*}_i of q^*(\gamma_i),
a vector of variance.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.