survregVB.frailty.fit.Calculates the variational Bayes convergence criteria, evidence lower
bound (ELBO), optimized in survregVB.frailty.fit.
elbo_cluster(
y,
X,
delta,
alpha_0,
omega_0,
mu_0,
v_0,
lambda_0,
eta_0,
alpha,
omega,
mu,
Sigma,
tau,
sigma,
lambda,
eta,
expectation_b,
cluster
)The evidence lower bound (ELBO).
A vector of observed log-transformed survival times.
A design matrix including covariates with first column of ones to represent the intercept.
A binary vector indicating right censoring.
The shape hyperparameter \(\alpha_0\) of the prior distribution of the scale parameter, b.
The shape hyperparameter \(\omega_0\) of the prior distribution of the scale parameter, b.
Hyperparameter \(\mu_0\), a vector of means, of the prior distribution of the vector of coefficients, \(\beta\).
The precision (inverse variance) hyperparameter \(v_0\), of the prior distribution of the vector of coefficients, \(\beta\).
The shape hyperparameter \(\lambda_0\) of the prior distribution of the frailty variance, \(\sigma_\gamma^2\).
The scale hyperparameter \(\eta_0\) of the prior distribution of the frailty variance, \(\sigma_\gamma^2\).
The shape parameter \(\alpha^*\) of \(q^*(b)\).
The scale parameter \(\omega^*\) of \(q^*(b)\).
Parameter \(\mu^*\) of \(q^*(\beta)\), a vector of means.
Parameter \(\Sigma^*\) of \(q^*(\beta)\), a covariance matrix.
Parameter \(\tau^*\) of \(q^*(\gamma_i)\), a vector of means.
Parameter \(\sigma^{2*}_i\) of \(q^*(\gamma_i)\), a vector of variance.
The shape parameter \(\lambda^*\) of \(q^*(\sigma^2_\gamma)\).
The scale parameter \(\eta^*\) of \(q^*(\sigma^2_\gamma)\).
The expected value of b.
A numeric vector indicating the cluster assignment for each observation.
survregVB.fit