survregVB.fit.Calculates parameter \(\mu^*\) of \(q^*(\beta)\) to optimize the
evidence based lower bound (ELBO) in survregVB.fit.
mu_star(y, X, delta, mu_0, v_0, alpha, omega, mu, Sigma, expectation_b)Parameter \(\mu^*\) of \(q^*(\beta)\).
A vector of observed log-transformed survival times.
A design matrix including covariates with first column of ones to represent the intercept.
A binary vector indicating right censoring.
Hyperparameter \(\mu_0\), a vector of means, of the prior distribution of the vector of coefficients, \(\beta\).
The precision (inverse variance) hyperparameter \(v_0\), of the prior distribution of the vector of coefficients, \(\beta\).
The shape parameter \(\alpha^*\) of \(q^*(b)\).
The scale parameter \(\omega^*\) of \(q^*(b)\).
Parameter \(\mu^*\) of \(q^*(\beta)\), a vector of means.
Parameter \(\Sigma^*\) of \(q^*(\beta)\), a covariance matrix.
The expected value of b.
survregVB.fit