survregVB.fit.Calculates parameter \(\omega^*\) of \(q^*(b)\) to optimize the
evidence based lower bound (ELBO) in survregVB.fit.
omega_star(y, X, delta, omega_0, mu, expectation_b)Parameter \(\omega^*\) of \(q^*(b)\).
A vector of observed log-transformed survival times.
A design matrix including covariates with first column of ones to represent the intercept.
A binary vector indicating right censoring.
The shape hyperparameter \(\omega_0\) of the prior distribution of the scale parameter, b.
Parameter \(\mu^*\) of \(q^*(\beta)\), a vector of means.
The expected value of b.
survregVB.fit